@@ -6,5 +6,5 @@ folder_path = os.path.abspath(
     os.path.join(os.path.dirname(inspect.getfile(inspect.currentframe()))))
 
 
-def get_chromedriver_path():
-    return os.path.join(folder_path, 'chromedriver')
+def get_vjs_path():
+    return os.path.join(folder_path, 'get_player_url.js')
