@@ -25,6 +25,7 @@ menu type:
 '''
 # 已登录的可选择项
 LOGINED_ITEMS = [
+    Item('local_history_list', '本地历史', 'display_local_history_list'),
     Item('history_list', '历史记录', 'display_history_list'),
     Item('collect_list', '我的收藏', 'display_collect_list'),
     Item('logout', '退出登陆', 'user_logout'),
@@ -93,8 +94,8 @@ class Index():
 
         self._init_player()
 
-        # 是否下一首
-        self.is_next = 0
+        # 是否上/下一首
+        self.is_change = 0
 
         _thread.start_new_thread(self._bg, ())
 
@@ -128,10 +129,10 @@ class Index():
 
     def _bg(self):
         while True:
-            # 是否下一首
-            if self.is_next == 1:
-                self._play()
-                self.is_next = 0
+            # 是否上/下一首
+            if self.is_change == 1:
+                self._play(isnew=True)
+                self.is_change = 0
             # 标题移动
             if self.current_play and self.player.is_playing():
                 self.current_play.cursor = self.current_play.cursor + 1 \
@@ -146,7 +147,15 @@ class Index():
     def play_next_cb(self, event):
         LOG.debug('play next...')
         self.current_play = self.ximalaya.get_next_track(self.current_play.id)
-        self.is_next = 1
+        self.is_change = 1
+        self.log_string = '播放下一首'
+
+    @vlc.callbackmethod
+    def play_pre_cb(self, event):
+        LOG.debug('play pre...')
+        self.current_play = self.ximalaya.get_pre_track(self.current_play.id)
+        self.is_change = 1
+        self.log_string = '播放上一首'
 
     @vlc.callbackmethod
     def update_time(self, event):
@@ -200,7 +209,7 @@ class Index():
         if not self.current_play:
             LOG.warn('cannot save the current play object to history file')
             return
-        self.storage.current_paly = self.current_play
+        self.storage.add_current_play(self.current_play)
         self.storage.volume = self.player.get_volume()
         self.storage.rate = self.player.get_rate()
         self.storage.save()
@@ -222,7 +231,7 @@ class Index():
             tmp_x = x + self.weight - wcswidth(userstr)
             self.display_info(userstr, tmp_x, y, 1)
 
-        self.display_info('-' * self.weight, x, y + 1)
+        self.display_info('\u2500' * self.weight, x, y + 1)
         nar_str = ''
         for obj in self.menu_stack.get_raw():
             if obj.get('type') == 0:
@@ -234,7 +243,7 @@ class Index():
             elif obj.get('type') == 3:
                 nar_str += ' / Exit'
         self.display_info(nar_str, x, y + 2)
-        self.display_info('-' * self.weight, x, y + 3)
+        self.display_info('\u2500' * self.weight, x, y + 3)
 
     def display_body(self):
         self._display_menu()
@@ -295,19 +304,20 @@ class Index():
                                         self.current_play.position)
 
             cursor = self.current_play.cursor
-            max_len = 20
+            max_len = 24
             play_display_name = self.current_play.name
             # play_display_name 长度不能大于 max_len
             if len(play_display_name) >= max_len:
                 play_display_name = play_display_name[:19]
 
             self.display_info(
-                '$ %s' % get_pretty_str(play_display_name, cursor, max_len), x,
-                y, 5)
+                '\u266a %s' %
+                get_pretty_str(play_display_name, cursor, max_len), x, y, 5)
 
-        self.display_info('[速率: %s]' % round(self.storage.rate, 1), x + 42,
-                          y - 1, 5)
-        self.display_info('[音量: %s]' % self.storage.volume, x + 42, y, 5)
+        self.display_info('[\u2261 速率: %s]' % round(self.storage.rate, 1),
+                          x + 42, y - 1, 5)
+        self.display_info('[\u25c0 音量: %s' % self.storage.volume, x + 42, y, 5)
+        self.display_info(']', x + 54, y, 5)
         self.display_info(
             '[%s%s][%s/%s]' %
             ('=' * play_progress_bar_len, '-' *
@@ -326,34 +336,34 @@ class Index():
 
     def _display_help(self):
         x = self._x + 27
-        y = self._y + 6
+        y = self._y + 7
+        self.display_info('-' * 27, x, y - 1, 5)
+        help_items = [
+            ('?', '帮助'),
+            ('Backspace', '返回上一步'),
+            ('+', '音量增加'),
+            ('-', '音量减小'),
+            (')', '速率增加'),
+            ('(', '速率减小'),
+            ('->', '快进'),
+            ('<-', '快退'),
+            ('>', '上一首'),
+            ('<', '下一首'),
+            ('q', '退出'),
+        ]
+        for k, v in help_items:
+            self.display_info(
+                '|%s%s%s%s%s|' %
+                (' ' * (10 - wcswidth(k)), k, ' ' * 5, v, ' ' *
+                 (10 - wcswidth(v))), x, y, 5)
+            y += 1
         self.display_info('-' * 27, x, y, 5)
-        self.display_info('|%s?%s%s%s|' % (' ' * 9, ' ' * 5, '帮助', ' ' * 6), x,
-                          y + 1, 5)
-        self.display_info(
-            '|%sBackspace%s%s%s|' % (' ' * 1, ' ' * 5, '返回上一步', ' ' * 0), x,
-            y + 2, 5)
-        self.display_info('|%s+%s%s%s|' % (' ' * 9, ' ' * 5, '音量增加', ' ' * 2),
-                          x, y + 3, 5)
-        self.display_info('|%s-%s%s%s|' % (' ' * 9, ' ' * 5, '音量减小', ' ' * 2),
-                          x, y + 4, 5)
-        self.display_info('|%s+%s%s%s|' % (' ' * 9, ' ' * 5, '速率增加', ' ' * 2),
-                          x, y + 5, 5)
-        self.display_info('|%s-%s%s%s|' % (' ' * 9, ' ' * 5, '速率减小', ' ' * 2),
-                          x, y + 6, 5)
-        self.display_info('|%s>%s%s%s|' % (' ' * 9, ' ' * 5, '快进', ' ' * 6), x,
-                          y + 7, 5)
-        self.display_info('|%s<%s%s%s|' % (' ' * 9, ' ' * 5, '快退', ' ' * 6), x,
-                          y + 8, 5)
-        self.display_info('|%sq%s%s%s|' % (' ' * 9, ' ' * 5, '退出', ' ' * 6), x,
-                          y + 9, 5)
-        self.display_info('-' * 27, x, y + 10, 5)
 
     def display_footer(self):
         x = self._x
         y = self._y + 25
-        self.display_info('-' * self.weight, x, y)
-        self.display_info('key: %s' % self.key, x, y + 1, 1)
+        self.display_info('\u2500' * self.weight, x, y)
+        self.display_info(self.key, x, y + 1, 1)
         log_tmp_x = x + self.weight - wcswidth(self.log_string)
         self.display_info(self.log_string, log_tmp_x, y + 1, 1)
 
@@ -436,7 +446,7 @@ class Index():
                     LOG.debug('select meun: %s' % self.select_item)
                     self.current_play = self.select_item
                     self.log_string = 'play %s' % self.select_item.display_name
-                    self._play()
+                    self._play(isnew=True)
                 elif self.current_meun_type == 3:
                     LOG.debug('exit')
                     if self.islogin:
@@ -491,6 +501,13 @@ class Index():
                 if self.storage.rate > 0:
                     self.player.set_rate(self.storage.rate - 0.1)
 
+            # 下一首
+            elif key == ord('>') or key == 62:
+                self.play_next_cb(event=None)
+            # 上一首
+            elif key == ord('<') or key == 60:
+                self.play_pre_cb(event=None)
+
             # 快进/快退
             elif key == 261:
                 self.player.set_time(self.current_play.time + 3)
@@ -557,6 +574,12 @@ class Index():
             self._modify_current_items(history.get('data'))
         self.select_index = 0
 
+    def display_local_history_list(self):
+        """显示本地历史记录"""
+        history = self.storage.local_history
+        self.menu_stack.push({'type': 2, 'items': history})
+        self.select_index = 0
+
     def display_chapter_list(self, album, is_page=False):
         """显示专辑的章节记录"""
         tracks = self.ximalaya.get_track_list(album.id, page_num=self.page_num)
@@ -570,7 +593,7 @@ class Index():
             self._modify_current_items(tracks.get('data'))
         self.select_index = 0
 
-    def _play(self):
+    def _play(self, isnew=False):
         if not self.current_play.src:
             self.current_play.src = self.ximalaya.get_track_src(
                 self.current_play.id)
@@ -579,5 +602,6 @@ class Index():
                   (self.current_play.name, self.current_play.src,
                    self.current_play.time, self.current_play.length,
                    self.player.play()))
-        self.player.set_time(self.current_play.time)
+        if not isnew:
+            self.player.set_time(self.current_play.time)
         self.save_history()
